# Migration of SAP LeanIX Academy Courses to SAP Learning
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/migration-of-sap-leanix-academy-courses-to-sap-learning#overview)
  * [What You Need to Do](https://help.sap.com/docs/leanix/ea/migration-of-sap-leanix-academy-courses-to-sap-learning#what-you-need-to-do)
  * [Download Your Course History and Certificates from SAP LeanIX Academy](https://help.sap.com/docs/leanix/ea/migration-of-sap-leanix-academy-courses-to-sap-learning#download-your-course-history-and-certificates-from-sap-leanix-academy)
  * [Courses on SAP Learning: Links](https://help.sap.com/docs/leanix/ea/migration-of-sap-leanix-academy-courses-to-sap-learning#courses-on-sap-learning:-links)
  * [FAQs](https://help.sap.com/docs/leanix/ea/migration-of-sap-leanix-academy-courses-to-sap-learning#faqs)


SAP LeanIX Academy is being sunset, and all courses are moving to SAP Learning. Learn what to expect and how to prepare for this transition.
